@@ -7,7 +7,6 @@ import logging
 import pathlib
 import textwrap
 import typing as t
-from typing import overload
 
 from libvcs.__about__ import __version__ as libvcs_version
 
@@ -18,10 +17,12 @@ from ._formatter import VcspullHelpFormatter
 from .add import add_repo, create_add_subparser, handle_add_command
 from .discover import create_discover_subparser, discover_repos
 from .fmt import create_fmt_subparser, format_config_file
+from .import_cmd import create_import_subparser
 from .list import create_list_subparser, list_repos
 from .search import create_search_subparser, search_repos
 from .status import create_status_subparser, status_repos
 from .sync import create_sync_subparser, sync
+from .worktree import create_worktree_subparser, handle_worktree_command
 
 log = logging.getLogger(__name__)
 
@@ -55,10 +56,10 @@ CLI_DESCRIPTION = build_description(
         (
             "sync",
             [
-                'vcspull sync "*"',
+                "vcspull sync --all",
                 'vcspull sync "django-*"',
-                'vcspull sync --dry-run "*"',
-                'vcspull sync -f ./myrepos.yaml "*"',
+                "vcspull sync --dry-run --all",
+                "vcspull sync -f ./myrepos.yaml --all",
                 "vcspull sync -w ~/code myproject",
             ],
         ),
@@ -105,6 +106,15 @@ CLI_DESCRIPTION = build_description(
                 "vcspull fmt --all",
             ],
         ),
+        (
+            "import",
+            [
+                "vcspull import github torvalds -w ~/repos/linux --mode user",
+                "vcspull import github django -w ~/study/python --mode org",
+                "vcspull import gitlab gitlab-org/ci-cd -w ~/work --mode org",
+                "vcspull import codeberg user -w ~/oss --json",
+            ],
+        ),
     ),
 )
 
@@ -116,10 +126,10 @@ SYNC_DESCRIPTION = build_description(
         (
             None,
             [
-                'vcspull sync "*"',
+                "vcspull sync --all",
                 'vcspull sync "django-*"',
-                'vcspull sync --dry-run "*"',
-                'vcspull sync -f ./myrepos.yaml "*"',
+                "vcspull sync --dry-run --all",
+                "vcspull sync -f ./myrepos.yaml --all",
                 "vcspull sync -w ~/code myproject",
             ],
         ),
@@ -234,14 +244,61 @@ FMT_DESCRIPTION = build_description(
     ),
 )
 
+IMPORT_DESCRIPTION = build_description(
+    """
+    Import repositories from remote services.
 
-@overload
+    Fetches repository lists from a remote hosting service and adds them to
+    the vcspull configuration.  Choose a service subcommand for details:
+
+      github (gh)       GitHub or GitHub Enterprise
+      gitlab (gl)       GitLab (gitlab.com or self-hosted)
+      codeberg (cb)     Codeberg
+      gitea             Self-hosted Gitea instance
+      forgejo           Self-hosted Forgejo instance
+      codecommit (cc)   AWS CodeCommit
+    """,
+    (
+        (
+            None,
+            [
+                "vcspull import github torvalds -w ~/repos/linux",
+                "vcspull import gh django -w ~/study/python --mode org",
+                "vcspull import gitlab mygroup -w ~/work --mode org",
+                "vcspull import codecommit -w ~/work/aws --region us-east-1",
+            ],
+        ),
+    ),
+)
+
+WORKTREE_DESCRIPTION = build_description(
+    """
+    Manage git worktrees for repositories.
+
+    Worktrees allow checking out multiple branches/tags/commits of a repository
+    simultaneously in separate directories.
+    """,
+    (
+        (
+            None,
+            [
+                "vcspull worktree list",
+                "vcspull worktree sync",
+                "vcspull worktree sync --dry-run",
+                "vcspull worktree prune",
+            ],
+        ),
+    ),
+)
+
+
+@t.overload
 def create_parser(
     return_subparsers: t.Literal[True],
 ) -> tuple[argparse.ArgumentParser, t.Any]: ...
 
 
-@overload
+@t.overload
 def create_parser(return_subparsers: t.Literal[False]) -> argparse.ArgumentParser: ...
 
 
@@ -333,6 +390,24 @@ def create_parser(
     )
     create_fmt_subparser(fmt_parser)
 
+    # Import command
+    import_parser = subparsers.add_parser(
+        "import",
+        help="import repositories from remote services",
+        formatter_class=VcspullHelpFormatter,
+        description=IMPORT_DESCRIPTION,
+    )
+    create_import_subparser(import_parser)
+
+    # Worktree command
+    worktree_parser = subparsers.add_parser(
+        "worktree",
+        help="manage git worktrees",
+        formatter_class=VcspullHelpFormatter,
+        description=WORKTREE_DESCRIPTION,
+    )
+    create_worktree_subparser(worktree_parser)
+
     if return_subparsers:
         # Return all parsers needed by cli() function
         return parser, (
@@ -343,6 +418,8 @@ def create_parser(
             add_parser,
             discover_parser,
             fmt_parser,
+            import_parser,
+            worktree_parser,
         )
     return parser
 
@@ -354,10 +431,12 @@ def cli(_args: list[str] | None = None) -> None:
         sync_parser,
         _list_parser,
         _status_parser,
-        _search_parser,
-        _add_parser,
-        _discover_parser,
+        search_parser,
+        add_parser,
+        discover_parser,
         _fmt_parser,
+        _import_parser,
+        _worktree_parser,
     ) = subparsers
     args = parser.parse_args(_args)
 
@@ -384,7 +463,9 @@ def cli(_args: list[str] | None = None) -> None:
             fetch=getattr(args, "fetch", False),
             offline=getattr(args, "offline", False),
             verbosity=getattr(args, "verbosity", 0),
+            sync_all=getattr(args, "sync_all", False),
             parser=sync_parser,
+            include_worktrees=getattr(args, "include_worktrees", False),
         )
     elif args.subparser_name == "list":
         list_repos(
@@ -395,6 +476,7 @@ def cli(_args: list[str] | None = None) -> None:
             output_json=args.output_json,
             output_ndjson=args.output_ndjson,
             color=args.color,
+            include_worktrees=getattr(args, "include_worktrees", False),
         )
     elif args.subparser_name == "status":
         status_repos(
@@ -409,6 +491,9 @@ def cli(_args: list[str] | None = None) -> None:
             max_concurrent=getattr(args, "max_concurrent", None),
         )
     elif args.subparser_name == "search":
+        if not args.query_terms:
+            search_parser.print_help()
+            return
         search_repos(
             query_terms=args.query_terms,
             config_path=pathlib.Path(args.config) if args.config else None,
@@ -425,8 +510,14 @@ def cli(_args: list[str] | None = None) -> None:
             match_any=getattr(args, "match_any", False),
         )
     elif args.subparser_name == "add":
+        if not args.repo_path:
+            add_parser.print_help()
+            return
         handle_add_command(args)
     elif args.subparser_name == "discover":
+        if not args.scan_dir:
+            discover_parser.print_help()
+            return
         discover_repos(
             scan_dir_str=args.scan_dir,
             config_file_path_str=args.config,
@@ -435,6 +526,7 @@ def cli(_args: list[str] | None = None) -> None:
             yes=args.yes,
             dry_run=args.dry_run,
             merge_duplicates=args.merge_duplicates,
+            include_worktrees=getattr(args, "include_worktrees", False),
         )
     elif args.subparser_name == "fmt":
         format_config_file(
@@ -443,3 +535,13 @@ def cli(_args: list[str] | None = None) -> None:
             args.all,
             merge_roots=args.merge_roots,
         )
+    elif args.subparser_name == "import":
+        handler = getattr(args, "import_handler", None)
+        if handler is None:
+            _import_parser.print_help()
+            return
+        result = handler(args)
+        if result:
+            raise SystemExit(result)
+    elif args.subparser_name == "worktree":
+        handle_worktree_command(args)
